**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name             modelEco__techn1.gms
Sequence         2 - The farm model
Type             LP
GAMS language    Data and variables with two indices (two dimensions)
Description
"A given farm can grow three types of crop, wheat, maize and tomato,
and use two different crop practices, extensive and intensive.
The area to be cultivated and technology to be used must be determined, knowing that :
The objective of the farmer is to maximize his income.

Labour needs are as follows :
                 Labour needs (h/ha)
Technology        Extensive        Intensive
Wheat             15                 25
Maize             45                 50
Tomato            80                 100

Yields and costs are as follows :
                    Yield (ton/ha)                        Cost (/ha)
Technology       Extensive        Intensive      Extensive        Intensive
Wheat             4.5             5.0             250             300
Maize             8.0             10.0            400             500
Tomato           13.0            16.0            1200            1350

The selling price of wheat is 150/ton, that of maize is 150/ton, and that of tomato 185/ton.
The farm area is 50 ha, and the farmer can work 2000 hours a year."


$Offtext


*----------                          DECLARATIONS                        ----------*
sets
C crops      /wheat, maize, tomato/
T Technology /ext, int/
;

*----------                          DATA                        ----------*
scalar
LAND_A    land availability in hectares          /50/
LABOUR_A  labour availability in hours           /2000/
;

table
LN(C, T) labour needs per hectare and per crop (hours)
          ext   int
wheat     15    25
maize     45    50
tomato    80   100
;

table
YLD (C, T) yield per crop in tonnes per hectare
           ext     int
wheat      4.5     5.0
maize      8.0    10.0
tomato    13.0    16.0
;

parameter
PC (C)  selling price per crop in euros
/ wheat    150
  maize    150
  tomato   185/
;

table
COST (C, T) cost per crop in euros per ha
          ext    int
wheat     250    300
maize     400    500
tomato   1200   1350
;

parameter
GM(C, T) gross margin per crop in euros    ;
GM(C, T) = YLD(C, T)*PC(C)-COST(C, T);

*----------                         MODEL                          ----------*
variables
Z     total farm income  (euros)
;

positive variables
X    area per crop (hectares)
;

equations
OBJECTIVE       objective function
LAND            land equation
LABOUR          labour equation
;

OBJECTIVE..      sum ((C,T), GM(C, T)* X(C, T)) =E= Z ;

LAND..           sum((C,T), X(C, T)) =l= LAND_A ;

LABOUR..         sum((C,T), LN(C, T)*X(C, T)) =L= LABOUR_A;

model modelS2 first example /all/;

*----------                        SOLUTION                         ----------*
solve modelS2 using LP maximizing Z;

